@@ -67,8 +67,11 @@ typedef enum
   // BUDDHA cheat
   CF_BUDDHA           = 8,
   // NOTARGET cheat
-  CF_NOTARGET         = 16
+  CF_NOTARGET         = 16,
 
+  CF_MAPCOORDS        = 32,
+  CF_RENDERSTATS      = 64,
+  CF_SHOWFPS          = 128,
 } cheat_t;
 
 
@@ -181,6 +184,7 @@ typedef struct player_s
   // [crispy] free look / mouse look
   int                 lookdir, oldlookdir;
   boolean             centering;
+  fixed_t             slope;
 
   // [crispy] weapon recoil pitch
   fixed_t             recoilpitch, oldrecoilpitch;
