@@ -27,6 +27,7 @@
 #include "i_oalmusic.h"
 
 #include "doomtype.h"
+#include "i_printf.h"
 #include "i_system.h"
 #include "i_sound.h"
 #include "m_misc2.h"
@@ -58,7 +59,7 @@ static uint32_t FL_Callback(uint8_t *buffer, uint32_t buffer_samples)
 
     if (result != FLUID_OK)
     {
-        fprintf(stderr, "FL_Callback: Error generating FluidSynth audio\n");
+        I_Printf(VB_ERROR, "FL_Callback: Error generating FluidSynth audio");
     }
 
     return buffer_samples;
@@ -194,11 +195,27 @@ static void FreeSynthAndSettings(void)
     }
 }
 
+static void I_FL_Log_Error(int level, const char *message, void *data)
+{
+  I_Printf(VB_ERROR, "%s", message);
+}
+
+static void I_FL_Log_Debug(int level, const char *message, void *data)
+{
+  I_Printf(VB_DEBUG, "%s", message);
+}
+
 static boolean I_FL_InitMusic(int device)
 {
     int sf_id;
     int lumpnum;
 
+    fluid_set_log_function(FLUID_PANIC, I_FL_Log_Error, NULL);
+    fluid_set_log_function(FLUID_ERR,   I_FL_Log_Error, NULL);
+    fluid_set_log_function(FLUID_WARN,  I_FL_Log_Debug, NULL);
+    fluid_set_log_function(FLUID_INFO,  NULL,           NULL);
+    fluid_set_log_function(FLUID_DBG,   NULL,           NULL);
+
     settings = new_fluid_settings();
 
     fluid_settings_setnum(settings, "synth.sample-rate", SND_SAMPLERATE);
@@ -224,8 +241,8 @@ static boolean I_FL_InitMusic(int device)
 
     if (synth == NULL)
     {
-        fprintf(stderr,
-                "I_FL_InitMusic: FluidSynth failed to initialize synth.\n");
+        I_Printf(VB_ERROR,
+                "I_FL_InitMusic: FluidSynth failed to initialize synth.");
         return false;
     }
 
@@ -289,7 +306,7 @@ static boolean I_FL_InitMusic(int device)
         return false;
     }
 
-    printf("FluidSynth Init: Using '%s'.\n",
+    I_Printf(VB_INFO, "FluidSynth Init: Using '%s'.",
         lumpnum >= 0 ? "SNDFONT lump" : soundfont_path);
 
     return true;
@@ -346,8 +363,8 @@ static void *I_FL_RegisterSong(void *data, int len)
 
     if (player == NULL)
     {
-        fprintf(stderr,
-                "I_FL_InitMusic: FluidSynth failed to initialize player.\n");
+        I_Printf(VB_ERROR,
+                "I_FL_InitMusic: FluidSynth failed to initialize player.");
         return NULL;
     }
 
@@ -380,7 +397,7 @@ static void *I_FL_RegisterSong(void *data, int len)
     {
         delete_fluid_player(player);
         player = NULL;
-        fprintf(stderr, "I_FL_RegisterSong: Failed to load in-memory song.\n");
+        I_Printf(VB_ERROR, "I_FL_RegisterSong: Failed to load in-memory song.");
         return NULL;
     }
 
