@@ -423,7 +423,8 @@ extern boolean colored_blood;
 // equilateral triangle (i.e. 60°) for the vertical FOV which spans
 // 200 px, so the height of that triangle would be 100*sqrt(3) = 173.
 #define PLAYER_SLOPE(a)	((((a)->lookdir / MLOOKUNIT) << FRACBITS) / 160)
-extern boolean direct_vertical_aiming;
+extern boolean direct_vertical_aiming, default_direct_vertical_aiming;
+void P_UpdateDirectVerticalAiming(void);
 
 mobj_t *P_SubstNullMobj(mobj_t *mobj);
 void    P_RespawnSpecials(void);
