@@ -435,6 +435,7 @@ void R_SetViewSize(int blocks)
 void R_ExecuteSetViewSize (void)
 {
   int i, j;
+  extern void AM_Start(void);
 
   setsizeneeded = false;
 
@@ -542,11 +543,15 @@ void R_ExecuteSetViewSize (void)
         }
     }
 
-    HU_disableAllWidgets();
+    HU_disable_all_widgets();
 
     // [crispy] forcefully initialize the status bar backing screen
     ST_refreshBackground(true);
 
+    // [FG] reinitialize Automap
+    if (automapactive)
+        AM_Start();
+
     // [FG] spectre drawing mode
     R_SetFuzzColumnMode();
 
